Ruleset

Enum Ruleset 

pub enum Ruleset<'a, T> {
    SelectorRuleset(SelectorRuleset<'a, T>),
    QualRule(QualRule<'a>),
    QualRuleset(QualRuleset<'a, T>),
    QualNestedRuleset(QualNestedRuleset<'a, T>),
}
A collection of rules (or other T), delimited by {}. Ruleset is generic over the specific type of its rules field, which ultimately determines whether this struct is recursive (in its TreeRuleset variant) or not (in its FlatRuleset variant).

Ruleset implements RenderCss, but the more-specific type alias TreeRuleset implements ParseCss.

Not allowed:

@media (max-width:1250px) {
    color: green;
    div {
        color: red;
    }
}

Variants



SelectorRuleset(SelectorRuleset<'a, T>)



QualRule(QualRule<'a>)



QualRuleset(QualRuleset<'a, T>)



QualNestedRuleset(QualNestedRuleset<'a, T>)

Implementations

Source

impl<'a> Ruleset<'a, TreeRule<'a>>

pub fn flatten_tree(&self) -> Vec<FlatRuleset<'a>>

Flatten into a FlatRuleset, replacing this struct’s inner TreeRule recursive type with a regular Rule, removing arbitrary nesting of SelectorRuleset variants.