Struct procss::ast::Tree

source ·
pub struct Tree<'a>(_);
A nested CSS representation yielded from parsing. Tree also implements RenderCss if this is needed, though this output can’t be read by browsers and is not identical to the input since whitespace has been discarded.

Implementations

Flatten a nested Tree into a Css, or in other words, convert the result of a parse into something that can be rendered.

A mutable transform which walks this AST recursively, invoking f for all nodes of type T.

Example
use procss::{ast, parse, RenderCss};
let mut tree = parse("div{color: red;}").unwrap();
tree.transform(|rule: &mut ast::Rule| {
    rule.value = "green".into();
});

let css = tree.flatten_tree().as_css_string();
assert_eq!(css, "div{color:green;}");

Iterate over the immediate children of this Tree (non-recursive).