Struct procss::BuildCss

source ·
pub struct BuildCss { /* private fields */ }
A CSS+ project build, comprising a collection of CSS+ files which may reference eachother (via @import).

Implementations

An incremental build struct for compiling a project’s CSS sources.

Example

let mut build = procss::BuildCss::new("./src");
build.add("app.scss");
build.compile("./dist").unwrap();

Create a new BuildCss rooted at rootdir.

Add a file path to this build.

Compile this BuildCss start-to-finish, applying all transforms along the way. Resulting files are written to outdir, preserving their paths relative to rootdir used to construct this BuildCss.