pub struct BuildCss { /* private fields */ }
A CSS+ project build, comprising a collection of CSS+ files which may
reference eachother (via @import).
An incremental build struct for compiling a project’s CSS sources.
let mut build = procss::BuildCss::new("./src");
build.add("app.scss");
build.compile("./dist").unwrap();
Create a new BuildCss rooted at rootdir.
Add a file path to this build.
Compile this BuildCss start-to-finish, applying all transforms along
the way. Resulting files are written to outdir, preserving their paths
relative to rootdir used to construct this BuildCss.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.